@@ -39,7 +39,6 @@ class VmCommand(PluginCommand):
                 vm start [NAMES] [--dryrun]
                 vm terminate [NAMES] [--cloud=CLOUD] [--dryrun]
                 vm delete [NAMES] [--cloud=CLOUD] [--dryrun]
-                vm refresh [--cloud=CLOUDS]
                 vm list [NAMES]
                         [--cloud=CLOUDS]
                         [--output=OUTPUT]
@@ -52,7 +51,6 @@ class VmCommand(PluginCommand):
                         [--username=USERNAME]
                         [--image=IMAGE]
                         [--flavor=FLAVOR]
-                        [--size=SIZE]
                         [--network=NETWORK]
                         [--public]
                         [--secgroup=SECGROUP]
@@ -251,7 +249,6 @@ class VmCommand(PluginCommand):
                        'image',
                        'interval',
                        'timeout',
-                       'ip',
                        'key',
                        'modify-knownhosts',
                        'n',
@@ -260,7 +257,6 @@ class VmCommand(PluginCommand):
                        'quiet',
                        'secgroup',
                        'size',
-                       'username',
                        'output',
                        'count',
                        'network',
@@ -278,69 +274,69 @@ class VmCommand(PluginCommand):
                                                 arguments,
                                                 variables)
 
-        if (arguments.meta and arguments.list):
+        if arguments.meta:
 
             name = arguments.NAME
+
             if arguments.NAME is None:
                 name = variables['vm']
                 if name is None:
                     Console.error("No vm specified")
 
-            cloud = "chameleon"
-            # cloud = Parameter.find(arguments, variables)
-            print(f"vm metadata for {name} on {cloud}")
+            clouds = Arguments.get_clouds(arguments,
+                                          variables)
 
-            provider = Provider(name=cloud)
-            r = provider.get_server_metadata(name)
-            print(r)
-
-        elif arguments.meta and arguments.set:
-
-            metadata = {}
-            pairs = arguments['KEY=VALUE']
-            for pair in pairs:
-                key, value = pair.split("=", 1)
-                metadata[key] = value
-
-            name = arguments.NAME
-            if arguments.NAME is None:
-                name = variables['vm']
-                if name is None:
-                    Console.error("No vm specified")
-
-            cloud = "chameleon"
-            # cloud = Parameter.find(arguments, variables)
-            print(f"cloud {cloud} {name}")
-
-            provider = Provider(name=cloud)
-            provider.set_server_metadata(name, **metadata)
-            r = provider.get_server_metadata(name)
-
-            pprint(r)
-
-        elif arguments.meta and arguments.delete:
-
-            metadata = {}
-            keys = arguments['KEY']
-
-            name = arguments.NAME
-            if arguments.NAME is None:
-                name = variables['vm']
-                if name is None:
-                    Console.error("No vm specified")
-
-            cloud = "chameleon"
-            # cloud = Parameter.find(arguments, variables)
-            print(f"cloud {cloud} {name}")
+            cloud = clouds[0] or "chameleon"
 
             provider = Provider(name=cloud)
 
-            for key in keys:
-                provider.delete_server_metadata(name, key)
+            if arguments.list:
 
-            r = provider.get_server_metadata(name)
+                print(f"List metadata for {name} on {cloud}")
+                r = provider.get_server_metadata(name)
 
-            pprint(r)
+            elif arguments.set:
+
+                print(f"Set metadata for {name} on {cloud}")
+
+                metadata = {}
+                pairs = arguments['KEY=VALUE']
+                for pair in pairs:
+                    key, value = pair.split("=", 1)
+
+                    ##cm cannot be updated using vm meta set
+                    if key == 'cm':
+                        Console.warning("Update of cm metadata is not allowed.")
+                    else:
+                        metadata[key] = value
+
+                if len(metadata) < 1:
+                    Console.info("No metadata to update.")
+                    return
+
+                provider = Provider(name=cloud)
+                provider.set_server_metadata(name, **metadata)
+                r = provider.get_server_metadata(name)
+
+            elif arguments.delete:
+
+                print(f"Delete metadata for {name} on {cloud}")
+                metadata = {}
+                keys = arguments['KEY']
+
+                for key in keys:
+                    ##cm cannot be delete using vm meta set
+                    if key == 'cm':
+                        Console.warning("Deleting of cm metadata is not allowed.")
+                    else:
+                        provider.delete_server_metadata(name, key)
+
+                r = provider.get_server_metadata(name)
+
+            if r:
+                provider.Print(r,
+                               output=arguments.output,
+                               kind="metadata")
 
         elif arguments.list and arguments.refresh:
 
@@ -371,6 +367,10 @@ class VmCommand(PluginCommand):
 
             try:
 
+                if clouds is None:
+                    Console.error("No cloud specified")
+                    return ""
+
                 for cloud in clouds:
                     print(f"List {cloud}")
                     p = Provider(cloud)
@@ -626,7 +626,6 @@ class VmCommand(PluginCommand):
                         [--username=USERNAME]
                         [--image=IMAGE]
                         [--flavor=FLAVOR]
-                        [--size=SIZE]
                         [--network=NETWORK]
                         [--public]
                         [--secgroup=SECGROUP]
@@ -661,15 +660,14 @@ class VmCommand(PluginCommand):
                               "username",
                               "flavor",
                               "key",
-                              "size",
                               "network",
                               "secgroup"]:
-                parameters[attribute] = Parameter.find(attribute,
-                                                       arguments,
-                                                       variables.dict(),
-                                                       defaults)
-
-            if arguments.username is None:
+                if attribute is not None:
+                    parameters[attribute] = Parameter.find(attribute,
+                                                           arguments,
+                                                           variables.dict(),
+                                                           defaults)
+            if arguments["--username"] is None:
                 parameters.user = Image.guess_username(parameters.image)
 
             provider = Provider(name=cloud)
@@ -745,7 +743,6 @@ class VmCommand(PluginCommand):
                 else:
 
                     # parameters.progress = len(parameters.names) < 2
-
                     try:
                         vms = provider.create(**parameters)
                     except TimeoutError:
@@ -757,7 +754,7 @@ class VmCommand(PluginCommand):
                         print(e)
                         return ""
 
-                    variables['vm'] = str(n)
+                    variables['vm'] = str(name)
                     if arguments["-v"]:
                         banner("Details")
                         pprint(vms)
@@ -825,7 +822,7 @@ class VmCommand(PluginCommand):
                 Error.traceback(e)
                 Console.error("Problem renaming instances", traceflag=True)
 
-        elif arguments["ip"] and arguments["show"]:
+        elif arguments.ip and arguments["show"]:
             raise NotImplementedError
 
             print("show the ips")
@@ -838,14 +835,14 @@ class VmCommand(PluginCommand):
 
             """
 
-        elif arguments["ip"] and arguments["assign"]:
+        elif arguments.ip and arguments["assign"]:
             raise NotImplementedError
             """
             vm ip assign [NAMES] [--cloud=CLOUD]
             """
             print("assign the public ip")
 
-        elif arguments["ip"] and arguments["inventory"]:
+        elif arguments.ip and arguments["inventory"]:
             raise NotImplementedError
 
             """
